@@ -1,2 +1,2 @@
 from .pychance_class import PyChance
-from pychance import data
+from .data import SimpleTable
